from airflow import DAG
from airflow.operators.python import PythonOperator  # Airflow 2.x 기준
from datetime import datetime
from feed_parser.adapters.airflow_postgres_connection_provider import AirflowPostgresConnectionProvider
from feed_parser.core_parser.db_operations import DBOperations
from feed_parser.core_parser.parser import parse_rss_feed

def run_feed_parser(**kwargs):
    """
    Airflow 전용 연결 제공자를 이용해 DBOperations 인스턴스를 생성하고,
    파싱 작업을 실행합니다.
    """
    # Airflow Connection 정보를 사용해 AirflowPostgresConnectionProvider 인스턴스 생성
    provider = AirflowPostgresConnectionProvider(conn_id='aws-pg')
    # DBOperations 인스턴스 생성 (DI 방식)
    db_ops = DBOperations(provider)
    # 전체 피드 파싱 작업 실행
    parse_rss_feed(db_ops)

default_args = {
    'owner': 'airflow',
    'start_date': datetime(2023, 1, 1),
    'retries': 1,
}

with DAG(
    dag_id='my_feed_parser_dag',
    default_args=default_args,
    schedule_interval='@hourly',
    catchup=False,
    description='DAG to run the feed parser and store articles in the DB'
) as dag:
    
    feed_parser_task = PythonOperator(
        task_id='run_feed_parser',
        python_callable=run_feed_parser,
        provide_context=True  # Airflow 2에서는 자동으로 context를 전달함 (옵션)
    )

# DAG 정의 끝
