import unittest
from src.parsers.khan_parser import KhanParser
from src.parsers.base_parser import RSSParser
from datetime import datetime

class TestRSSParser(unittest.TestCase):

    def test_khan_extract_published_from_link(self):
        
        parser = KhanParser("TestPublisher", "TestCategory", "https://test.com")

        # 올바른 링크
        link = "https://www.khan.co.kr/article/202501162017005/?utm_source=khan_rss&utm_medium=rss&utm_campaign=total_news"
        result = parser.extract_published_from_link(link)
        self.assertEqual(result, "2025-01-16T20:17:00Z")

        # 잘못된 링크
        link = "https://example.com/no-article/"
        result = parser.extract_published_from_link(link)
        self.assertTrue("T" in result)  # 현재 시간 ISO 8601 형식 포함 여부 확인

        # None 링크
        result = parser.extract_published_from_link(None)
        current_time = datetime.now().isoformat()
        self.assertTrue(result[:10], current_time[:10])  # 날짜 부분 비교


    def test_chosun(self):
        url = "https://www.chosun.com/arc/outboundfeeds/rss/category/economy/?outputType=xml"
        publisher = "조선일보"
        categories = "_all_"
        parser = RSSParser(publisher=publisher, categories=categories, url=url)
        results = parser.parse_feed()
